==> dde-network-core_1.0.47.orig.tar.xz: dde-network-core-1.0.47/dss-network-plugin/translations/dss-network-plugin_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nowa wiadomość</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Łączenie %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 połączone</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 rozłączono</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Nie udało się połączyć z %1, prosimy sprawdzić router lub kabel sieciowy.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Nie udało się połączyć z %1, prosimy przybliżyć się do routera bezprzewodowego</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Połączenie nie powiodło się, nie udało połączyć się z %1, nieprawidłowe hasło</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Wymagane jest hasło, aby połączyć się z %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Nie można znaleźć sieci WLAN %1 802.11</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Połączenie przewodowe</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokół</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpieczenia</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pasmo</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanał</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfejs</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sieci</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Podstawowy DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Urządzenie wyłączone</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Połączono, brak dostępu do Internetu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nie połączono</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel sieciowy odłączony</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Łączenie</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Uwierzytelnianie</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Uzyskiwanie adresu IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Połączono</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Rozłączono</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Wystąpił błąd</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Uzyskiwanie adresu</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Połączenie przewodowe</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Połączenie przewodowe %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Połączenie bezprzewodowe %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Urządzenie wyłączone</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel sieciowy odłączony</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nie połączono</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Łączenie</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Połączono, brak dostępu do Internetu</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Połączenie nieudane</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Wyłącz połączenie przewodowe</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Włącz połączenie przewodowe</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Wyłącz połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Włącz połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Wyłącz sieć</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Włącz sieć</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ustawienia sieci</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nowa wiadomość</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Łączenie się z %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 połączone</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 rozłączono</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Nie udało się połączyć z %1, prosimy sprawdzić router lub kabel sieciowy.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Nie udało się połączyć z %1, prosimy przybliżyć się do routera bezprzewodowego</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Połączenie nie powiodło się, nie można połączyć z %1, nieprawidłowe hasło</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Wymagane jest hasło, aby połączyć się z %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Nie można znaleźć sieci WLAN %1 802.11</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Połączenie przewodowe</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokół</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpieczenia</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pasmo</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanał</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfejs</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sieci</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Podstawowy DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Urządzenie wyłączone</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Połączono, brak dostępu do Internetu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nie połączono</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel sieciowy odłączony</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Łączenie</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Uwierzytelnianie</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Uzyskiwanie adresu IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Połączono</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Rozłączono</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Wystąpił błąd</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Uzyskiwanie adresu</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Połączenie przewodowe</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Połączenie przewodowe %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Połączenie bezprzewodowe %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Urządzenie wyłączone</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel sieciowy odłączony</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nie połączono</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Łączenie</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Połączono, brak dostępu do Internetu</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Połączenie nieudane</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Wyłącz połączenie przewodowe</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Włącz połączenie przewodowe</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Wyłącz połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Włącz połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Wyłącz sieć</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Włącz sieć</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ustawienia sieci</translation>
    </message>
</context>
</TS>
